@@ -12,8 +12,9 @@
  @author Martin Petricek
 */
 
-#include "aboutwindow.h"
 #include "basegui.h"
+#include "qtcompat.h"
+#include "aboutwindow.h"
 #include "colortool.h"
 #include "commandwindow.h"
 #include "consolewritergui.h"
@@ -79,7 +80,7 @@ BaseGUI::~BaseGUI() {
  May be useful if you perform some lengthy operation to allow GUI to redraw
 */
 void BaseGUI::processEvents() {
- qApp->processEvents();
+ q_App->processEvents();
 }
 
 /**
@@ -131,7 +132,7 @@ void BaseGUI::runInitScript() {
  @param toolName Name of the tool affected
 */
 void BaseGUI::toolChangeValue(const QString &toolName) {
- guiPrintDbg(debug::DBG_DBG,"tool change: " << toolName);
+ guiPrintDbg(debug::DBG_DBG,"tool change: " << Q_OUT(toolName));
  //TODO: properly escape the name of tool
  call("onValueChange","'"+toolName+"'");
 }
@@ -239,7 +240,7 @@ void BaseGUI::addScriptingObjects() {
 */
 void BaseGUI::treeItemDeleted(TreeItemAbstract* theItem) {
  //Get dictionary with all wrappers for given treeitem
- QPtrDict<void>* pDict=treeWrap[theItem];
+ Q_PtrDict<void>* pDict=treeWrap[theItem];
  if (!pDict) {
   //No wrapper exists. Done.
   //guiPrintDbg(debug::DBG_DBG,"Item deleted that is not in wrapper"); 
@@ -248,12 +249,12 @@ void BaseGUI::treeItemDeleted(TreeItemAbstract* theItem) {
  //Ok, now disable all wrappers pointing to this item
 
  // For each wrapper
- QPtrDictIterator<void> it(*pDict);
+ Q_PtrDictIterator<void> it(*pDict);
  for(;it.current();++it) {
   QSTreeItem* theWrap=reinterpret_cast<QSTreeItem*>(it.currentKey());
   guiPrintDbg(debug::DBG_DBG,"Disabling wrapper " << (intptr_t)theWrap << " w. item "<< (intptr_t)theItem); 
   assert(theWrap);
-  guiPrintDbg(debug::DBG_DBG,"Check type: " << theWrap->type()); 
+  guiPrintDbg(debug::DBG_DBG,"Check type: " << Q_OUT(theWrap->type())); 
   //Disable the wrapper, so calling it will not result in crash, but some error/exception instead
   theWrap->disable();
   guiPrintDbg(debug::DBG_DBG,"Disabled wrapper"); 
@@ -383,7 +384,7 @@ QString BaseGUI::fileSaveDialogXml(const QString &oldName/*=QString::null*/) {
 */
 QVariant BaseGUI::getColor(const QString &colorName) {
  //Check if we have the picker
- if (!colorPickers.contains(colorName)) return QVariant();
+ if (!colorPickers.contains(colorName)) return QVariant();//NULL variant
  ColorTool *pick=colorPickers[colorName];
  assert(pick);
  return QVariant(pick->getColor());
@@ -488,8 +489,8 @@ QVariant BaseGUI::mergeDialog() {
   // if result length is 0 - there is nothing to merge
   int n=result->getLength();
   if(n>0) {
-   QValueList<QVariant> rItems;
-   QValueList<QVariant> rPos;
+   Q_List<QVariant> rItems;
+   Q_List<QVariant> rPos;
    // result->getItems() returns an array of pages to be merged
    // with current document
    int *res_items=result->getItems();
@@ -500,7 +501,7 @@ QVariant BaseGUI::mergeDialog() {
     rItems.append(res_items[i]);
     rPos.append((int)res_pos[i]);
    }
-   QValueList<QVariant> res;
+   Q_List<QVariant> res;
    res.append(rItems);
    res.append(rPos);   
    res.append(dialog->fileName());   
@@ -526,7 +527,7 @@ BaseGUI::selectPagesDialog (const QString& filename) const
 	typedef std::list<size_t> StdItems;
 
 	QVariant qvitems;				// Result of this function
-	QValueList<QVariant> qitems;	// Selected page numbers
+	Q_List<QVariant> qitems;	// Selected page numbers
 	scoped_ptr<SelectPagesDialog> dialog (new SelectPagesDialog(filename));	// Create dialog
 
 	// Starts dialog as modal and do something if OK is pressed
@@ -563,7 +564,7 @@ void BaseGUI::openFileNew(const QString &name) {
 
 /** Show options dialog. Does not wait for dialog to finish. */
 void BaseGUI::options() {
- OptionWindow::optionsDialog(w->menuSystem,w->allUnits());
+ OptionWindow::optionsDialog(w->menuSystem,w->allUnits(),w->allUnitIds());
 }
 
 /**
@@ -597,7 +598,7 @@ QSPage* BaseGUI::page() {
 QVariant BaseGUI::pickColor() {
  QColor ret=colorDialog(w);
  if (!ret.isValid()) {
-  return QVariant();
+  return QVariant();//NULL variant
   guiPrintDbg(debug::DBG_DBG,"Color is not valid");
  }
  return QVariant(ret);
@@ -641,6 +642,7 @@ int BaseGUI::question_ync(const QString &msg) {
   case 2: return -1;	//QMessageBox::Cancel
   default: assert(0);
  }
+ return -1;
 }
 
 /** \copydoc PdfEditWindow::restoreWindowState */
@@ -751,6 +753,30 @@ void BaseGUI::setPredefs(const QString &name,const QString &predefs) {
  return;
 }
 
+/**
+ Set tooltip for specified number edit box or select text box with given name.
+ @param name Name of edit box
+ @param tip text used as tooltip
+*/
+void BaseGUI::setTooltip(const QString &name,const QString &tip) {
+ //Check if we have the tool as number tool
+ if (numberTools.contains(name)) {
+  NumberTool *pick=numberTools[name];
+  assert(pick);
+  pick->setTooltip(tip);
+  return;
+ }
+ //Check if we have the tool as select text
+ if (selectTools.contains(name)) {
+  SelectTool *pick=selectTools[name];
+  assert(pick);
+  pick->setTooltip(tip);
+  return;
+ }
+ //Nope. Nothing
+ return;
+}
+
 /**
  Set predefined values to choose from for number edit box or select text box with given name.
  For number edit box, the user is still able to type its own numbers.
