@@ -7,6 +7,8 @@
  *
  * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
  */ 
+#include "pagespace.h"
+#include QSCROLLVIEW
 #include <stdlib.h>
 #include <math.h>
 
@@ -15,11 +17,11 @@
 #include <qmap.h>
 #include <qpixmap.h>
 #include <qimage.h>
-#include <qdockarea.h>
+//#include <qdockarea.h>
 #include <qfiledialog.h>
 #include <qmessagebox.h>
+#include QSTRLIST
 
-#include "pagespace.h"
 #include "settings.h"
 #include "cpdf.h"
 #include "cpage.h"
@@ -28,6 +30,9 @@
 
 #include "pageviewmode.h"
 #include "units.h"
+#ifdef QT4
+#include <QImageWriter>
+#endif
 
 /** Helpes struct for initializing width and height text labeles. */
 typedef struct { /** lebel width */ int labelWidth, /** label height */ labelHeight; } initStruct;
@@ -109,13 +114,14 @@ PageSpace::PageSpace(QWidget *parent /*=0*/, const char *name /*=0*/) : QWidget(
 	vBox = new QVBoxLayout(this);
 	
 	scrollPageSpace = pageImage = new PageViewS(this);
+	setFocusProxy(pageImage);
 	connect( pageImage, SIGNAL( changeMousePosition(double, double) ), this, SLOT( showMousePosition(double, double) ) );
 	connect( pageImage, SIGNAL( changeMousePosition(double, double) ), this, SIGNAL( changeMousePosition(double, double) ) );
 	vBox->addWidget(scrollPageSpace);
 //QObject *pomObj = this;
 //while (pomObj->parent() !=NULL) pomObj = pomObj->parent();
-QDockArea * da = new QDockArea( Qt::Horizontal, QDockArea::Normal, this /*dynamic_cast<QWidget *>(pomObj)*/ );
-vBox->addWidget( da );
+//QDockArea * da = new QDockArea( Qt::Horizontal, QDockArea::Normal, this /*dynamic_cast<QWidget *>(pomObj)*/ );
+//vBox->addWidget( da );
 	
 	hBox = new QHBoxLayout(vBox);
 
@@ -125,7 +131,7 @@ vBox->addWidget( da );
 
 	hBox->addStretch();
 	pageNumber = new QLabel( QString(tr("%1 of %2")).arg(0).arg(0), this, "cisStr" );
-	pageNumber->setAlignment( AlignCenter | pageNumber->alignment() );
+	pageNumber->setAlignment( Qt::AlignCenter | pageNumber->alignment() );
 	hBox->addWidget( pageNumber );
 	hBox->addStretch();
         
@@ -134,8 +140,8 @@ vBox->addWidget( da );
 	Init( &is , format + "00000000xx" );
 	mousePositionOnPage = new QLabel( format.arg(0.0,8,'g',6).arg(0.0,8,'g',6).arg( actualUnits.getDefaultUnits() ), this );
 	mousePositionOnPage->setMinimumWidth( is.labelWidth );
-	mousePositionOnPage->setAlignment( AlignRight | mousePositionOnPage->alignment() );
-	hBox->addWidget( mousePositionOnPage, 0, AlignRight);
+	mousePositionOnPage->setAlignment( Qt::AlignRight | mousePositionOnPage->alignment() );
+	hBox->addWidget( mousePositionOnPage, 0, Qt::AlignRight);
 
 	hBox->insertSpacing( 0, is.labelWidth );	// for center pageNumber
 
@@ -147,7 +153,7 @@ vBox->addWidget( da );
 	textLine->hide();
 
 	// if something use on page, take focus
-	setFocusPolicy( WheelFocus );
+	setFocusPolicy( TheWheelFocus );
 }
 
 PageSpace::~PageSpace() {
@@ -290,7 +296,7 @@ void PageSpace::unselectObjectOnPage ( ) {
 
 void PageSpace::setResizingZone ( int width ) {
 	if (width < 0) {
-		guiPrintDbg( debug::DBG_INFO, tr("Resizing zone must be positive integer or null !") );
+		guiPrintDbg( debug::DBG_INFO, "Resizing zone must be positive integer or null !" );
 		width = 0;
 	}
 	if (selectionMode)
@@ -357,10 +363,16 @@ bool PageSpace::isSomeoneSelected ( ) {
 
 bool PageSpace::saveImageWithDialog ( bool onlySelectedArea ) {
 	QString filters = "";
-	for (unsigned int i = 0; i < QImageIO::outputFormats().count() ;++i) {
+
+#ifdef QT4
+	QStrList lst=QImageWriter::supportedImageFormats();
+#else
+	QStrList lst=QImageIO::outputFormats();
+#endif
+	for (unsigned int i = 0; i < lst.count() ;++i) {
 		filters += QString("\n%1 (*.%2)")
-				.arg(QImageIO::outputFormats().at(i))
-				.arg(QString(QImageIO::outputFormats().at(i)).lower());
+				.arg(QString(lst.at(i)))
+				.arg(QString(lst.at(i)).lower());
 	}
 
 	QString sf;
@@ -399,7 +411,7 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 	tsp.yEnd = yEnd;
 
 	std::vector<Rectangle> recs;
-	int count = actualPage->findText( text, recs, tsp );
+	int count = actualPage->findText( util::convertFromUnicode(text,util::PDF), recs, tsp );
 
 	guiPrintDbg( debug::DBG_DBG, "Founded "<<count<<" items:");
 	for (std::vector<Rectangle>::iterator it = recs.begin(); it != recs.end() ; ++it) {
@@ -476,9 +488,13 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 }
 
 //----------------------------------------------------------------------
-QStringList PageSpace::getAllUnits ( ) {
+QStringList PageSpace::getAllUnits ( ) const {
 	return actualUnits.getAllUnits( );
 }
+
+QStringList PageSpace::getAllUnitIds ( ) const {
+	return actualUnits.getAllUnitIds( );
+}
 bool PageSpace::setDefaultUnits ( const QString dunits ) {
 		bool h = actualUnits.setDefaultUnits ( dunits );
 
