@@ -15,6 +15,12 @@
  * $RCSfile: cxref.h,v $
  *
  * $Log: cxref.h,v $
+ * Revision 1.28  2007/04/25 18:24:35  bilboq
+ *
+ * applied patch from Martin Michlmayr to fix compilation with gcc-4.3
+ *
+ * fixed some typos in comments
+ *
  * Revision 1.27  2007/02/04 20:17:02  mstsxfx
  * Common Licence comment for all cc and h files available in doc/licence_header
  * file and its content to all cc and h files in src/{gui,kernel,utils}
@@ -204,7 +210,7 @@ protected:
 	 * This constructor is protected to prevent uninitialized instances.
 	 * We need at least to specify stream with data.
 	 */
-	CXref(): XRef(NULL){};
+	CXref(): XRef(NULL){}
 
 	/** Entry for ObjectStorage.
 	 *
