@@ -13,6 +13,12 @@
  * $RCSfile: pdfwriter.h,v $
  *
  * $Log: pdfwriter.h,v $
+ * Revision 1.12  2007/04/25 18:24:35  bilboq
+ *
+ * applied patch from Martin Michlmayr to fix compilation with gcc-4.3
+ *
+ * fixed some typos in comments
+ *
  * Revision 1.11  2007/02/04 20:17:02  mstsxfx
  * Common Licence comment for all cc and h files available in doc/licence_header
  * file and its content to all cc and h files in src/{gui,kernel,utils}
@@ -160,7 +166,7 @@ public:
 	/** Default virtual destructor.
 	 * Empty destructor.
 	 */
-	virtual ~IProgressBar(){};
+	virtual ~IProgressBar(){}
 	
 	/** Starts progress visualization.
 	 */
@@ -335,7 +341,7 @@ public:
 		size_t objNum;
 	};
 
-	virtual ~IPdfWriter(){};
+	virtual ~IPdfWriter(){}
 
 	/** Puts all objects to given stream.
 	 * @param objectList List of objects to store.
@@ -434,7 +440,7 @@ public:
 	 *
 	 * Initializes CONTENT and TRAILER fields to default values.
 	 */
-	OldStylePdfWriter():maxObjNum(0), CONTENT("Content phase"), TRAILER("XREF/TRAILER phase"){};
+	OldStylePdfWriter():maxObjNum(0), CONTENT("Content phase"), TRAILER("XREF/TRAILER phase"){}
 
 	/** Writes given objects.
 	 * @param objectList List of objects to write.
